@@ -14,11 +14,32 @@ def start(args):
     parser.add_option("--ssl-key", dest="ssl_key", help="Private key for serving SSL")
     parser.add_option("--ssl-cert", dest="ssl_cert", help="Certificate for serving SSL")
     parser.add_option("--proxy-request-timeout", dest="proxy_request_timeout", default=20, type="float", help="Proxy timeout in seconds")
+    parser.add_option("--client-key", dest="client_key", help="Private key for client certificate")
+    parser.add_option("--client-cert", dest="client_cert", help="Certificate for client authentication")
 
     (options, params) = parser.parse_args(args)
 
     mallory.logs.setup()
-    server = mallory.Server(proxy_to=params[0], port=options.port, ca_file=options.ca_cert, request_timeout=options.proxy_request_timeout, ssl_options={ "certfile": options.ssl_cert, "keyfile": options.ssl_key })
+
+    ssl_options = {
+        "certfile": options.ssl_cert,
+        "keyfile": options.ssl_key
+    }
+
+    http_request_options = {
+        "client_cert": options.client_cert,
+        "client_key": options.client_key,
+        "ca_certs": options.ca_cert,
+        "request_timeout": options.proxy_request_timeout
+    }
+
+    server = mallory.Server(
+        proxy_to=params[0],
+        port=options.port,
+        ssl_options=ssl_options,
+        http_request_options=http_request_options
+    )
+
     handle_interrupt(server)
 
     logging.info("starting mallory on port %s" % options.port)
@@ -33,4 +54,3 @@ def handle_interrupt(server):
         sys.exit(0)
 
     signal.signal(signal.SIGINT, signal_handler)
-
